/**
 * Copyright (C) 2015, The Open Telecoms Project, http://opentelecoms.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
package javax.sip;

import javax.sip.Dialog;
import javax.sip.message.Request;
import java.io.Serializable;

public interface Transaction extends Serializable {

	public Dialog getDialog();

	public TransactionState getState();

	public int getRetransmitTimer() throws UnsupportedOperationException;

	public void setRetransmitTimer(int retransmitTimer)
			throws UnsupportedOperationException;

	public String getBranchId();

	public Request getRequest();

	public void setApplicationData(Object applicationData);

	public Object getApplicationData();

	public void terminate() throws ObjectInUseException;
}
